@@ -20,6 +20,8 @@ Sub-packages
  chemistry           --- abstract data structure for chemistry
  nanosci             --- nano-science tools
  physics             --- physics tools
+ scripts             --- scripts
+ tools               --- tools
 
 ::
 
@@ -28,6 +30,6 @@ Sub-packages
 """
 from __future__ import print_function, absolute_import
 
-__all__ = ['chemistry', 'nanosci', 'physics']
+__all__ = ['chemistry', 'nanosci', 'physics', 'scripts', 'tools']
 
 from pksci.version import version as __version__
